const std = @import("std");
const jetzig = @import("jetzig");

pub const layout = "panel";

const Article = struct {
    title: [255]u8,
    blob: [255]u8
};

pub fn index(request: *jetzig.Request, data: *jetzig.Data) !jetzig.View {
    var root = try data.object();
    const cookies = try request.cookies();

    const query = jetzig.database.Query(.Blog).orderBy(.{.created_at = .desc});
    const blogs = try request.repo.all(query);

    try root.put("articles", blogs);

    const allowed = blk: {
        const session = cookies.get("session") orelse break :blk false;

        const session_query = jetzig.database.Query(.Session)
            .findBy(.{ .session_id = session.value });
        _ = request.repo.execute(session_query) catch break :blk false;
        break :blk true;
    };

    try root.put("allowed", allowed);

    // Set arbitrary response headers as required. `content-type` is automatically assigned for
    // HTML, JSON responses.
    //
    // Static files located in `public/` in the root of your project directory are accessible
    // from the root path (e.g. `public/jetzig.png`) is available at `/jetzig.png` and the
    // content type is inferred from the extension using MIME types.
    try request.response.headers.append("x-example-header", "example header value");

    // Render the response and set the response code.
    return request.render(.ok);
}
